@@ -18,8 +18,8 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 #include "libxnee/xnee.h"
@@ -333,7 +333,20 @@ xnee_renew_xnee_data(xnee_data *xd)
    ret = xnee_new_dyn_data(xd);
    XNEE_RETURN_IF_ERR (ret);
 
-   return (XNEE_OK);
+
+   /*
+    * Reset counters...
+    */
+   xd->first_read_time = 0;
+   
+   xd->meta_data.sum_max    = 0;
+   xd->meta_data.sum_min    = 0;
+   
+   xd->meta_data.total_diff = 0;
+   xd->meta_data.cached_max = 0;
+   xd->meta_data.cached_min = 0;
+  
+  return (XNEE_OK);
 }
 
 int
